summaryrefslogtreecommitdiffstats
path: root/Source/cmCTest.h
diff options
context:
space:
mode:
authorZack Galbreath <zack.galbreath@kitware.com>2019-08-20 14:55:12 (GMT)
committerZack Galbreath <zack.galbreath@kitware.com>2019-08-22 17:10:18 (GMT)
commit2a71a0390c6c1130c9b50f717a751dc815310073 (patch)
tree319c7b5059a1a9eae5ae322410c4f2c4e56b34ef /Source/cmCTest.h
parent43fe736b2bf272647fb24b481bdc9a585c0666ac (diff)
downloadCMake-2a71a0390c6c1130c9b50f717a751dc815310073.zip
CMake-2a71a0390c6c1130c9b50f717a751dc815310073.tar.gz
CMake-2a71a0390c6c1130c9b50f717a751dc815310073.tar.bz2
ctest: rename TRACK to GROUP
Update command-line options, script variables, and documentation to use the term "group" instead of "track". The old terms are still available for now, but they are now undocumented. This makes our terminology more consistent with CDash. The goal of this change is to make it more clear to our users how CTest and CDash interact with each other.
Diffstat (limited to 'Source/cmCTest.h')
-rw-r--r--Source/cmCTest.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/Source/cmCTest.h b/Source/cmCTest.h
index 7f66378..7fe3455 100644
--- a/Source/cmCTest.h
+++ b/Source/cmCTest.h
@@ -404,9 +404,9 @@ public:
std::vector<std::string>& GetInitialCommandLineArguments();
- /** Set the track to submit to */
- void SetSpecificTrack(const char* track);
- const char* GetSpecificTrack();
+ /** Set the group to submit to */
+ void SetSpecificGroup(const char* group);
+ const char* GetSpecificGroup();
void SetFailover(bool failover);
bool GetFailover() const;